==> react-sequence-viewer-0.1.0.tgz: package/es/index.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { PropTypes, Component } from 'react';

import Bootstrap from 'bootstrap/dist/css/bootstrap.min.css';
// See nwb.config.js for some webpack magic that allows this to work.
import Sequence from 'sequence-viewer';

var ReactSequenceViewer = function (_Component) {
    _inherits(ReactSequenceViewer, _Component);

    function ReactSequenceViewer(props) {
        _classCallCheck(this, ReactSequenceViewer);

        var _this = _possibleConstructorReturn(this, _Component.call(this, props));

        _this.handleChange = _this.handleChange.bind(_this);

        // Initialize the sequence-viewer object.
        _this._seqObj = new Sequence(_this.props.sequence);
        _this._div = null;
        return _this;
    }

    // Function to call the render function of sequence-viewer.
    // You can override existing props by passing an object with key value
    // pairs to override existing props.
    // e.g.
    // callRender({toolbar: false})
    // would override the existing toolbar setting.


    ReactSequenceViewer.prototype.callRender = function callRender() {
        var newProps = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];

        // Read in div from private variable.
        var div = this._div;
        //Render div if it is not null.
        if (div != null) {
            this._seqObj.render('#' + div.id, _extends({}, this.props, newProps));
            this._seqObj.coverage(this.props.coverage);
            this._seqObj.addLegend(this.props.legend);
        }
    };

    // When the component mounts, add a change listenver to the document
    // and call render.  We attach the change listener here becuase
    // jQuery events don't see to bubble up through React properly.
    // Thus, when a user toggles the charsPerLine drop down menu.
    // the event is handled by jQuery, but not seen by React when the
    // listener is attached at the component div level.
    // Attaching it to the document seems to work.


    ReactSequenceViewer.prototype.componentDidMount = function componentDidMount() {
        document.addEventListener('change', this.handleChange);
        this.callRender();
        this._seqObj.onSubpartSelected(this.props.onSubpartSelected);
        this._seqObj.onMouseSelection(this.props.onMouseSelection);
    };

    // Remove the event listener when the component is unmounted.


    ReactSequenceViewer.prototype.componentWillUnmount = function componentWillUnmount() {
        document.removeEventListener('change', this.handleChange);
    };

    // Function called when the user changes the charsPerLine setting via the toolbar.


    ReactSequenceViewer.prototype.handleChange = function handleChange(e) {
        var elem = e.target;
        // Check that the event was triggered by the right <select> button.
        if ((" " + elem.className + " ").indexOf(" " + this.props.seqLenClass + " ") > -1) {
            // Call render and override the charsPerLine setting with whatever the user specified.
            this.callRender({ charsPerLine: elem.value });
        }
    };

    // Render a div with the sequence-viwer widget in it.


    ReactSequenceViewer.prototype.render = function render() {
        var _this2 = this;

        var _props = this.props;
        var id = _props.id;
        var sequence = _props.sequence;
        var className = _props.className;
        // Create the container div and store a reference to it once it is mounted
        // in the DOM.  The componentDidMount function above will then get called
        // and render the widget.

        return React.createElement(
            'div',
            { className: className },
            React.createElement('div', { id: this.props.id, ref: function ref(div) {
                    return _this2._div = div;
                } })
        );
    };

    return ReactSequenceViewer;
}(Component);

export { ReactSequenceViewer as default };


process.env.NODE_ENV !== "production" ? ReactSequenceViewer.propTypes = {
    id: PropTypes.string.isRequired,
    sequence: PropTypes.string.isRequired,
    coverage: PropTypes.arrayOf(PropTypes.shape({
        start: PropTypes.number.isRequired,
        end: PropTypes.number.isRequired,
        color: PropTypes.string,
        bgcolor: PropTypes.string,
        underscore: PropTypes.bool,
        tooltip: PropTypes.string,
        onclick: PropTypes.func
    })),
    legend: PropTypes.arrayOf(PropTypes.shape({
        name: PropTypes.string,
        color: PropTypes.string,
        underscore: PropTypes.bool
    })),
    seqLenClass: PropTypes.string,
    onMouseSelection: PropTypes.func,
    onSubpartSelected: PropTypes.func
} : void 0;

ReactSequenceViewer.defaultProps = {
    coverage: [],
    legend: [],
    seqLenClass: "CPLChoice",
    onMouseSelection: function onMouseSelection(elem) {},
    onSubpartSelected: function onSubpartSelected(elem) {},
    className: ''
};

==> react-sequence-viewer-0.1.2.tgz: package/es/index.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { PropTypes, Component } from 'react';
import { v4 } from 'uuid';

import Bootstrap from 'bootstrap/dist/css/bootstrap.min.css';
// See nwb.config.js for some webpack magic that allows this to work.
import Sequence from 'sequence-viewer';

var ReactSequenceViewer = function (_Component) {
    _inherits(ReactSequenceViewer, _Component);

    function ReactSequenceViewer(props) {
        _classCallCheck(this, ReactSequenceViewer);

        var _this = _possibleConstructorReturn(this, _Component.call(this, props));

        _this.handleChange = _this.handleChange.bind(_this);

        if (props.selection && props.selection.length > 0 && props.coverage && props.coverage.length > 0) {
            console.warn("The selection and coverage options are not compatible with each other.");
        }
        // Initialize the sequence-viewer object.
        _this._seqObj = new Sequence(_this.props.sequence);
        _this._div = null;
        return _this;
    }

    // Function to call the render function of sequence-viewer.
    // You can override existing props by passing an object with key value
    // pairs to override existing props.
    // e.g.
    // callRender({toolbar: false})
    // would override the existing toolbar setting.


    ReactSequenceViewer.prototype.callRender = function callRender() {
        var newProps = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
        var _props = this.props;
        var selection = _props.selection;

        var props = _objectWithoutProperties(_props, ['selection']);

        // Read in div from private variable.


        var div = this._div;

        //Render div if it is not null.
        if (div !== null) {
            var _seqObj;

            this._seqObj.render('#' + div.id, _extends({}, props, newProps));
            this._seqObj.coverage(this.props.coverage);
            this._seqObj.addLegend(this.props.legend);
            if (selection.length > 0) (_seqObj = this._seqObj).selection.apply(_seqObj, selection);
        }
    };

    // When the component mounts, add a change listenver to the document
    // and call render.  We attach the change listener here becuase
    // jQuery events don't see to bubble up through React properly.
    // Thus, when a user toggles the charsPerLine drop down menu.
    // the event is handled by jQuery, but not seen by React when the
    // listener is attached at the component div level.
    // Attaching it to the document seems to work.


    ReactSequenceViewer.prototype.componentDidMount = function componentDidMount() {
        document.addEventListener('change', this.handleChange);
        this.callRender();
        this._seqObj.onSubpartSelected(this.props.onSubpartSelected);
        this._seqObj.onMouseSelection(this.props.onMouseSelection);
    };

    // Remove the event listener when the component is unmounted.


    ReactSequenceViewer.prototype.componentWillUnmount = function componentWillUnmount() {
        document.removeEventListener('change', this.handleChange);
    };

    // Function called when the user changes the charsPerLine setting via the toolbar.


    ReactSequenceViewer.prototype.handleChange = function handleChange(e) {
        var elem = e.target;
        // Check that the event was triggered by the right <select> button.
        if ((" " + elem.className + " ").indexOf(" " + this.props.seqLenClass + " ") > -1) {
            // Call render and override the charsPerLine setting with whatever the user specified.
            this.callRender({ charsPerLine: elem.value });
        }
    };

    // Render a div with the sequence-viwer widget in it.


    ReactSequenceViewer.prototype.render = function render() {
        var _this2 = this;

        var _props2 = this.props;
        var id = _props2.id;
        var sequence = _props2.sequence;
        var className = _props2.className;
        // Create the container div and store a reference to it once it is mounted
        // in the DOM.  The componentDidMount function above will then get called
        // and render the widget.

        return React.createElement('div', { className: className, id: this.props.id, ref: function ref(div) {
                return _this2._div = div;
            } });
    };

    return ReactSequenceViewer;
}(Component);

export { ReactSequenceViewer as default };


process.env.NODE_ENV !== "production" ? ReactSequenceViewer.propTypes = {
    id: PropTypes.string,
    sequence: PropTypes.string.isRequired,
    className: PropTypes.string,
    selection: PropTypes.arrayOf(function (arr, key, compName, location, propFullName) {
        if (arr.length !== 3) {
            return new Error('Invalid prop `selection` supplied to `' + compName + '`. Validation failed.');
        }
    }),
    coverage: PropTypes.arrayOf(PropTypes.shape({
        start: PropTypes.number.isRequired,
        end: PropTypes.number.isRequired,
        color: PropTypes.string,
        bgcolor: PropTypes.string,
        underscore: PropTypes.bool,
        tooltip: PropTypes.string,
        onclick: PropTypes.func
    })),
    legend: PropTypes.arrayOf(PropTypes.shape({
        name: PropTypes.string,
        color: PropTypes.string,
        underscore: PropTypes.bool
    })),
    seqLenClass: PropTypes.string,
    onMouseSelection: PropTypes.func,
    onSubpartSelected: PropTypes.func
} : void 0;

ReactSequenceViewer.defaultProps = {
    id: v4(),
    coverage: [],
    legend: [],
    selection: [],
    seqLenClass: "CPLChoice",
    onMouseSelection: function onMouseSelection(elem) {},
    onSubpartSelected: function onSubpartSelected(elem) {},
    className: ''
};
